utils

|  | ## Cheshire3: utils Module

Module utils

Classes | [hide private]
reader |
SimpleBitfield |

Functions | [hide private]
saxToString(data)
fixString(s)
evaluateXPath(xp, dom)
flattenTexts(elem)
getFirstElement(elem) Find first child which is an Element
getFirstData(elem) Find first child which is Data
getFirstElementByTagName(node, local)
traversePath(node)
verifyXPaths(paths)
parseSrbUrl(data)

Variables | [hide private]
nonTextToken |
use4Suite |
elementType |
textType |

Function Details | [hide private]

### saxToString(data) | source code

### fixString(s) | source code

### evaluateXPath(xp, dom) | source code

### flattenTexts(elem) | source code

### getFirstElement(elem) | source code
Find first child which is an Element

### getFirstData(elem) | source code
Find first child which is Data

### getFirstElementByTagName(node, local) | source code

### traversePath(node) | source code

### verifyXPaths(paths) | source code

### parseSrbUrl(data) | source code

Variables Details | [hide private]

    ### nonTextToken Value:
        '\x00\t'

    ### use4Suite Value:
        1

    ### elementType Value:
        1

    ### textType Value:
        3